@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2003 - 2011 by Claude Bulin
+ * copyright : (C) 2003 - 2012 by Claude Bulin
  *
  * xcfa - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
@@ -526,6 +526,20 @@ gint libutils_getNbProcess( void )
 	closedir( Repo );
 	return( pNbr );
 }
+// 
+// 
+gchar *libutils_string_toupper( gchar *p_str )
+{
+	gchar	*Str = g_strdup( p_str );
+	gchar	*Ptr = Str;
+	
+	while( Ptr && *Ptr ) {
+		*Ptr = g_ascii_toupper( *Ptr );
+		Ptr ++;
+	}
+	
+	return( Str );
+}
 
 
 
