@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -181,20 +181,20 @@ void AlsaPlay_song (gchar *NameFile, gdouble PBegin, gdouble PEnd, void *p_FuncS
 {
 	pthread_t	nmr_tid;
 	gboolean	BoolOpenDevice = FALSE;
-	WAVE		son;
+	WAVE		WaveHeader;
 	
-	if (FALSE == tagswav_read_file (NameFile, &son)) {
-		tagswav_close_file (&son);
+	if (FALSE == tagswav_read_file (NameFile, &WaveHeader)) {
+		tagswav_close_file (&WaveHeader);
 		if( TRUE == OptionsCommandLine.BoolVerboseMode )
 			g_print ("\nImpossible d'ouvrir le fichier : \"%s\"\n\n", NameFile);
 		return;
 	}
 	
 	// OUVERTURE FICHIER ET TRANSMISSION DU HANDLE
-	VarAlsa.pFile = son.file;
-	son.file = NULL;
+	VarAlsa.pFile = WaveHeader.file;
+	WaveHeader.file = NULL;
 	
-	switch (son.FMT.BitsPerSample) {
+	switch (WaveHeader.FMT.BitsPerSample) {
 	case 8 :
 	case 16 :
 	case 24 :
@@ -206,27 +206,27 @@ void AlsaPlay_song (gchar *NameFile, gdouble PBegin, gdouble PEnd, void *p_FuncS
 		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
 			g_print("Seuls ces formats de bitrates : 8 16 24 et 32 sont pris en charge pour la lecture\n"
 				"Format de bitrate [ %d ] non prit en charge\n", 
-				son.FMT.BitsPerSample);
+				WaveHeader.FMT.BitsPerSample);
 			g_print("NO MUSIC :/\n");
 		}
 		return;
 	}
 	
 	// DUREE EN SECONDES DU FICHIER
-	VarAlsa.Sec          = son.DATA.Subchunk2Size / son.FMT.ByteRate;
+	VarAlsa.Sec          = WaveHeader.DATA.Subchunk2Size / WaveHeader.FMT.ByteRate;
 	VarAlsa.PercentBegin = PBegin;
 	VarAlsa.PercentEnd   = PEnd;
 	
 	// TAILLE DES DATA AUDIO EN OCTETS
-	VarAlsa.TotalChunckSize = son.DATA.Subchunk2Size;
+	VarAlsa.TotalChunckSize = WaveHeader.DATA.Subchunk2Size;
 	
 	// TEST OUVERTURE DEVICE
 	BoolOpenDevice = AlsaAudio_open_device(
-			"default",			// const char *audio_dev,		default
-			son.FMT.BitsPerSample,		// int p_bitsPerSample,			8, 16, 24, ...
-			son.FMT.NumChannels,		// int p_channels,			1, 2, 4, ...
-			son.FMT.SampleRate,		// unsigned int p_samplesPerSec		44100, ...
-			&VarAlsa.SizeBuffer		// unsigned int *p_bufferSize,		Taille buffer retournee
+			"default",				// const char *audio_dev,		default
+			WaveHeader.FMT.BitsPerSample,		// int p_bitsPerSample,			8, 16, 24, ...
+			WaveHeader.FMT.NumChannels,		// int p_channels,			1, 2, 4, ...
+			WaveHeader.FMT.SampleRate,		// unsigned int p_samplesPerSec		44100, ...
+			&VarAlsa.SizeBuffer			// unsigned int *p_bufferSize,		Taille buffer retournee
 			);
 	
 	if (BoolOpenDevice == TRUE) {
@@ -248,7 +248,7 @@ void AlsaPlay_song (gchar *NameFile, gdouble PBegin, gdouble PEnd, void *p_FuncS
 		AlsaAudio_close_device ();
 		PRINT_FUNC_LF();
 		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
-			g_print("Format de bitrate [ %d ] non prit en charge\n", son.FMT.BitsPerSample);
+			g_print("Format de bitrate [ %d ] non prit en charge\n", WaveHeader.FMT.BitsPerSample);
 			g_print("NO MUSIC :/\n");
 		}
 	}
