@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -105,7 +105,7 @@ static gint cdaudiotoc_timeout_do_read_toc_cd (gpointer data)
 				cdaudio_affiche_glist_audio ();
 				cdaudio_set_flag_buttons ();
 				cdaudio_put_label_duree (EnteteCD.StrDureeCd);
-				cdaudio_put_label_titre (EnteteCD.TitleCD);
+				cdaudio_put_label_titre (EnteteCD.TitleCD != NULL ? EnteteCD.TitleCD : "");
 
 				OptionsCd_set_entry_and_label();
 				
