@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -888,6 +888,10 @@ void CdCurl_discdb_do_read( DO_CURL_QUERY p_DoCurlQuery )
 			Audio->Str_Track		= g_strdup_printf ( "%02d", Track + 1 );
 			Audio->Duree			= g_strdup( VarSector.ListSector[ Track ].StrTime );
 			Audio->NameSong			= libutils_dup_chomp(  PtrNameTrack );
+			if( NULL != ( PtrNameTrack = strchr( Audio->NameSong, '/' ))) {
+				*PtrNameTrack = '-';
+			}
+
 			VarSector.ListSector[ Track ].Title = g_strdup( Audio->NameSong	);
 		
 			Audio->tags = ( TAGS * )tags_alloc( TRUE );
