@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -487,45 +487,27 @@ void on_entry_tag_genre_realize( GtkWidget *widget, gpointer user_data )
 	gtk_entry_completion_set_model( completion, GTK_TREE_MODEL(model) );
 }
 // 
-// 
-gboolean cdexpander_bool_entree_cd_verif_car = TRUE;
-// 
 // Saisie CD -> ARRANGEMENT DES TITRES DU CD
 // 
 void on_entry_new_titre_cdaudio_changed (GtkEditable *editable, gpointer user_data)
 {
-	if (cdexpander_bool_entree_cd_verif_car == FALSE) return;
+	if( FALSE == var_cd.bool_enter_parse ) return;
+	var_cd.bool_enter_parse = FALSE;
 	
 	if (NULL != var_cd.Adr_entry_new_titre_cdaudio) {
-		gchar	*StrVerif = NULL;
-		gchar	*ptr = NULL;
 		
 		// SUPPRESSION DE LA LIGNE SAISIE PAR L UTILISTATEUR
 		if (NULL != Config.Templates_title_cdaudio) {
 			g_free (Config.Templates_title_cdaudio);
 			Config.Templates_title_cdaudio = NULL;
 		}
-		
-		// LA CARACTERE / EST INTERDIT
-		StrVerif = g_strdup ((gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_new_titre_cdaudio)));
-		if (strchr (StrVerif, '/')) {
-			cdexpander_bool_entree_cd_verif_car = FALSE;
-			while ((ptr = strchr (StrVerif, '/'))) {
-				strcpy (ptr, ptr+1);
-			}
-			gtk_entry_set_text (GTK_ENTRY (var_cd.Adr_entry_new_titre_cdaudio), StrVerif);
-			cdexpander_bool_entree_cd_verif_car = TRUE;
-		}
-		// STOCKAGE DE LA LIGNE SAISIE PAR L UTILISTATEUR
-		Config.Templates_title_cdaudio = g_strdup (StrVerif);
-		
-		g_free (StrVerif);
-		StrVerif = NULL;
+		Config.Templates_title_cdaudio = g_strdup( (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_new_titre_cdaudio)) );
 		
 		Parse_entry (PARSE_TYPE_TITLE_CD);
 
 		cdaudio_set_titre_chanson ();
 	}
+	var_cd.bool_enter_parse = TRUE;
 }
 // 
 // 
@@ -590,6 +572,7 @@ void on_entry_tag_titre_fichier_m3u_realize (GtkWidget *widget, gpointer user_da
 // 
 void on_entry_new_titre_cdaudio_realize (GtkWidget *widget, gpointer user_data)
 {
+	var_cd.bool_enter_parse = TRUE;
 	var_cd.Adr_entry_new_titre_cdaudio = widget;
 	if (NULL == Config.Templates_title_cdaudio) {
 		Config.Templates_title_cdaudio = g_strdup ("%c %d");
