@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -42,6 +42,7 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
+// #include <fcntl.h>	// PROCESSUS NON-BLOQUANT
 
 #ifdef ENABLE_STATIC_LIBRARY
 	#include "../lib/lib.h"
@@ -164,7 +165,8 @@ void conv_sigchld_extract (gint signum)
 }
 int conv_extract_call_exec (gchar **args, pid_t *p, gint p_output)
 {
-	gchar **ptr = (gchar **)args;
+	gchar	**ptr = (gchar **)args;
+	// gint	status;
 
 	conv.signal_numchildren_extract = 0;
 	if (pipe (conv.tube_extract) != 0)
@@ -183,6 +185,11 @@ int conv_extract_call_exec (gchar **args, pid_t *p, gint p_output)
 	conv.signal_numchildren_extract ++;
 	signal (SIGCHLD, conv_sigchld_extract);
 	close(conv.tube_extract [ 1 ]);
+	
+	// LE FICHIER EST OUVERT EN MODE « NON-BLOQUANT »
+	// status = fcntl( conv.tube_extract [ 0 ], F_GETFL );
+	// status = fcntl( conv.tube_extract [ 0 ], F_SETFL, status | O_NONBLOCK );
+	
 	return (conv.tube_extract [ 0 ]);
 }
 /*
@@ -207,7 +214,8 @@ void conv_sigchld_convert (gint signum)
 }
 int conv_call_exec (gchar **args, pid_t *p, gint p_output)
 {
-	gchar **ptr = (gchar **)args;
+	gchar	**ptr = (gchar **)args;
+	// gint	status;
 
 	conv.signal_numchildren_conv = 0;
 	if (pipe (conv.tube_conv) != 0)
@@ -226,6 +234,11 @@ int conv_call_exec (gchar **args, pid_t *p, gint p_output)
 	conv.signal_numchildren_conv ++;
 	signal (SIGCHLD, conv_sigchld_convert);
 	close (conv.tube_conv [ 1 ]);
+	
+	// LE FICHIER EST OUVERT EN MODE « NON-BLOQUANT »
+	// status = fcntl( conv.tube_conv [ 0 ], F_GETFL );
+	// status = fcntl( conv.tube_conv [ 0 ], F_SETFL, status | O_NONBLOCK );
+	
 	return (conv.tube_conv [ 0 ]);
 }
 // RESET STRUCTURE CONV
@@ -311,17 +324,17 @@ void conv_with_lsdvd_ARGS (gchar **args)
 // 
 gboolean conv_with_mplayer_ARGS (gchar **args, TYPE_CONV p_TypeConv)
 {
-	gint      pos = 0;
-	gint      fd;
-	gint      size;
-	gchar     buf [ CONV_MAX_CARS + 10 ];
-	gboolean  BoolRet = TRUE;
-	gchar    *Ptr = NULL;
-	gboolean  BoolFinfTotal = FALSE;
-	gint      TimeTotal = 0;
-	gint      Secs = 0;
-	gint      Hundred = 0;
-	gboolean  BoolErreurMplayer = FALSE;
+	gint		pos = 0;
+	gint		fd;
+	gint		size;
+	gchar		buf [ CONV_MAX_CARS + 10 ];
+	gboolean	BoolRet = TRUE;
+	gchar		*Ptr = NULL;
+	gboolean	BoolFinfTotal = FALSE;
+	gint		TimeTotal = 0;
+	gboolean	BoolErreurMplayer = FALSE;
+	gint		Total = 0;
+	gint		Value = 0;
 	
 	/* PRINT_FUNC_LF(); */
 
@@ -362,37 +375,28 @@ gboolean conv_with_mplayer_ARGS (gchar **args, TYPE_CONV p_TypeConv)
 
 		if (TRUE == BoolErreurMplayer) break;
 
-		/*if (strcmp (buf, "Starting playback...") == 0) {
-			g_print ("Starting playback... TROUVé \n");
-		}
-		g_print ("%s", buf);*/
-		
 		if (FALSE == conv.bool_stop && p_TypeConv != MPLAYER_AUDIO_TO_WAV) {
-			/*
-			A:   7.3 (07.2) of 276.0 (04:36.0)  0.6%
-			*/
+			
+			// A:   7.3 (07.2) of 276.0 (04:36.0)  0.6%
+			// A:4061.6 ( 1:07:41.6) of 4089.0 ( 1:08:09.0)  0.0
+			
 			if (BoolFinfTotal == FALSE) {
 				if ((Ptr = strstr(buf,"A:")) != NULL) {
 					if ((Ptr = strstr(buf,"of")) != NULL) {
-						while (*Ptr != ' ') Ptr ++;
-						while (*Ptr == ' ') Ptr ++;
-						TimeTotal = atoi (Ptr);
+						Ptr ++;
+						Ptr ++;
+						Ptr ++;
+						sscanf( Ptr, "%d", &TimeTotal );
+						Total = TimeTotal;
 						BoolFinfTotal = TRUE;
 					}
 				}
 			}
-			else if (NULL != (Ptr = strstr(buf,"A:"))) {
-				Ptr += 2;
+			else if( buf[0] == 'A' && buf[1] == ':' ) {
+				Ptr = &buf[2];
 				while (*Ptr == ' ') Ptr++;
-				Secs = atoi (Ptr);
-				
-				while (*Ptr != '.') Ptr++;
-				if (*Ptr == '.') Ptr++;
-				
-				Hundred = atoi (Ptr);
-				conv.TimeMplayer = (gdouble)Secs + ((gdouble)Hundred / 10.0);
-							
-				conv.conversion_percent = (gdouble)Secs / (gdouble)TimeTotal;
+				sscanf( Ptr, "%d", &Value );
+				conv.conversion_percent = ( (double)Value / (double)Total ) ;
 				if (conv.conversion_percent >= CONV_MAX_VALUE_PERCENT) conv.conversion_percent = 1.000000;
 				conv.total_percent = ((double)conv.rip_completed +
 						      (double)conv.encode_completed +
@@ -430,16 +434,11 @@ gboolean conv_with_mplayer_ARGS (gchar **args, TYPE_CONV p_TypeConv)
 // 
 void conv_with_sox_ARGS (gchar **args)
 {
-	gint   fd;
-	gint   size;
-	gint   pos = 0;
-	gchar  buf [ CONV_MAX_CARS + 10 ];
-	gint   cent;
-	gint   min;
-	gint   sec;
-	gint   TT_Sector = -1;
-	gint   dummy;
-	gboolean BoolTst = FALSE;
+	gint	fd;
+	gint	size;
+	gint	pos = 0;
+	gchar	buf [ CONV_MAX_CARS + 10 ];
+	float	Percent;
 	
 	fd = conv_call_exec (args, &conv.code_fork_conv, STDERR_FILENO);
 
@@ -466,43 +465,24 @@ void conv_with_sox_ARGS (gchar **args)
 				conv_stop_conversion ();
 			}
 		}
-
-		/*
-		Time: 04:31.62 [00:00.00] of 04:31.62 ( 100.0%) Output Buffer:  11.98M
-		*/
-		if (strstr (buf, "Time: ")) BoolTst = TRUE;
-		if (TRUE == BoolTst && (buf[0] == '\0' || strstr (buf, "Input File     :"))) {
-			BoolTst = FALSE;
-			if (conv.encode_completed < conv.total_convert) {
-				// conv.encode_completed ++;
-				// g_print("conv.encode_completed = %d -> %d\n", conv.encode_completed -1, conv.encode_completed);
-				conv.bool_percent_conv = TRUE;
-				TT_Sector = -1;
-			}
-		}
 		
-		if (TT_Sector == -1) {
-			min = sec = cent = -1;
-			sscanf(buf, "Time: %d:%d.%d [%d:%d.%d] of %d:%d.%d",
-				&dummy, &dummy, &dummy, &dummy, &dummy, &dummy, &min, &sec, &cent);
-			if (min > -1 && sec > -1 && cent > -1) {
-				TT_Sector = ((min * 60) + sec);
-				/*g_print ("SEARCH BEGIN %d %d %d\n", min, sec, cent);*/
-			}
-		}
-		else /*if (strstr (buf, "Time: "))*/ {
-			min = sec = cent = -1;
-			sscanf(buf, "Time: %d:%d.%d", &min, &sec, &cent);
-			if (min > -1 && sec > -1 && cent > -1) {
-				conv.conversion_percent = (double)((min * 60) + sec) / TT_Sector;
-				if (conv.conversion_percent >= CONV_MAX_VALUE_PERCENT) conv.conversion_percent = 1.0;
-				// conv.total_percent = (conv.encode_completed + (double)((min * 60) + sec) / TT_Sector) / conv.total_convert;
-				conv.total_percent = ((double)conv.rip_completed +
-						      (double)conv.encode_completed +
-						      (double)conv.extract_percent +
-						      (double)conv.conversion_percent) /
-						      ((double)conv.total_rip + (double)conv.total_convert);
-				conv.bool_percent_conv = TRUE;
+		if( strstr( buf, "In:" )) {
+			
+			gchar	*Ptr = NULL;
+			
+			// In:76.6% 00:52:11.54 [00:15:58.40] Out:138M  [======|=====!] Hd:0.0 Clip:0    
+			if( NULL != ( Ptr = strchr( buf, ':' ))) {
+				Ptr ++ ;
+				if( sscanf( Ptr, "%f", &Percent ) > 0 ) {
+					conv.conversion_percent = (Percent / 100.0);
+					if (conv.conversion_percent >= CONV_MAX_VALUE_PERCENT) conv.conversion_percent = 1.0;
+					conv.total_percent = ((double)conv.rip_completed +
+							      (double)conv.encode_completed +
+							      (double)conv.extract_percent +
+							      (double)conv.conversion_percent) /
+							      ((double)conv.total_rip + (double)conv.total_convert);
+					conv.bool_percent_conv = TRUE;
+				}
 			}
 		}
 		
@@ -1089,7 +1069,7 @@ void conv_with_normalise_ARGS (gchar **args)
 	gint       pos = 0;
 	gboolean   bool_pass_2 = TRUE;
 
-	fd = conv_call_exec (args, &conv.code_fork_conv, STDOUT_FILENO);
+	fd = conv_call_exec (args, &conv.code_fork_conv, STDERR_FILENO);
 
 	do
 	{
@@ -1123,18 +1103,21 @@ void conv_with_normalise_ARGS (gchar **args)
 			}
 		}
 
-		// g_print("buf = %s\n", buf);
+		// g_print("BUF = %s\n", buf);
+		// 1_77842900.wav     35% done, ETA 00:00:02 (batch  35% done, ETA 00:00:02)
 		
-		if ((ptr = strstr (&buf[0], "batch"))) {
+		if( NULL != ( ptr = strstr( buf, "done" ))) {
 			
-			ptr += 6;
-			while (*ptr == ' ') ptr ++;
+			ptr --;
+			ptr --;
+			while( *ptr != ' ' ) ptr --;
+			ptr ++;
 			
 			if (sscanf(ptr, "%d",&end) == 1) {
 
 				if (bool_pass_2 == TRUE) {
 					if (end >= 100) bool_pass_2 = FALSE;
-					conv.conversion_percent = (double)((end * 0.1) / 10);
+					conv.conversion_percent = (double)end / 100.0;
 					if (conv.conversion_percent >= CONV_MAX_VALUE_PERCENT) conv.conversion_percent = 1.000000;
 					// conv.total_percent = (conv.encode_completed + (double)conv.conversion_percent) / conv.total_convert;
 					conv.total_percent = ((double)conv.rip_completed +
@@ -1145,8 +1128,14 @@ void conv_with_normalise_ARGS (gchar **args)
 					conv.bool_percent_conv = TRUE;
 				}
 				else {
-					conv.conversion_percent = (double)((end * 0.1) / 10);
+					// conv.conversion_percent = (double)((end * 0.1) / 10);
+					conv.conversion_percent = (double)end / 100.0;
 					if (conv.conversion_percent >= CONV_MAX_VALUE_PERCENT) conv.conversion_percent = 1.000000;
+					conv.total_percent = ((double)conv.rip_completed +
+							      (double)conv.encode_completed +
+							      (double)conv.extract_percent +
+							      (double)conv.conversion_percent) /
+							      ((double)conv.total_rip + (double)conv.total_convert);
 					conv.bool_percent_conv = TRUE;
 				}
 			}
@@ -2396,10 +2385,12 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 {
 	FILE	*fn = NULL;
 	FILE	*fe = NULL;
-	gchar	buf [ BUFSIZ ];
+	gchar	buf [ BUFSIZ + 10 ];	// 8192
 	size_t	size = libutils_get_size_file (filesrc);
 	gulong	blk;
 	gulong	cpt;
+	size_t	l_read;
+	
 	
 	if (0 == size) {
 		fprintf (stderr, "La taille de : %s est NULLE !!!\n", filesrc);
@@ -2427,9 +2418,8 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 	cpt = 0;
 	conv.BoolIsCopy = TRUE;
 	while ( ! feof (fe)) {
-		ssize_t	l;
 		
-		l = fread (buf, sizeof (*buf), BUFSIZ, fe);
+		l_read = fread (buf, sizeof (*buf), BUFSIZ, fe);
 		if (ferror (fe)) {
 			fprintf (stderr, "Erreur de lecture\n");
 			fclose (fn);
@@ -2438,7 +2428,7 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 			conv_inc_encode_completed ();
 			return (FALSE);
 		}
-		fwrite (buf, sizeof (*buf), l, fn);
+		fwrite (buf, sizeof (*buf), l_read, fn);
 		if (ferror (fn)) {
 			fprintf (stderr, "Erreur d'ecriture\n");
 			fclose (fn);
@@ -2447,6 +2437,7 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 			conv_inc_encode_completed ();
 			return (FALSE);
 		}
+		fflush( fn );
 		conv.conversion_percent = (double)cpt / (double)blk;
 		// if (conv.conversion_percent > 1.) conv.conversion_percent = 1.0;
 		// if (conv.conversion_percent < 0.) conv.conversion_percent = 0.0;
@@ -2463,6 +2454,8 @@ gboolean conv_copy_src_to_dest (gchar *filesrc, gchar *filedest)
 	conv.conversion_percent = 0.;
 	conv_inc_encode_completed ();
 	conv.BoolIsCopy = FALSE;
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\tOK\n");
 	
 	return (TRUE);
 }
