@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -133,7 +133,15 @@ static void filemp3oggconv_thread (void *arg)
 				*  RENAME soxwav TO wav
 				*/
 				if (InfoMp3->mpeg_is != MPEG_1) {
-					conv.encode_completed ++;
+
+					g_print ("SOURCE MP3<%s>\n", PConvMp3Ogg->destwav);
+					g_print ("DEST   WAV<%s>\n", PConvMp3Ogg->destsox);
+					conv_with_sox_get_param( PConvMp3Ogg->destwav, PConvMp3Ogg->destsox, "44100", "2", "16" );
+					conv_to_convert (FALSE, SOX_WAV_TO_WAV, "SOX_WAV_TO_WAV");
+					filelc_get_command_line_remove ();
+					conv_copy_src_to_dest (PConvMp3Ogg->destsox, PConvMp3Ogg->destwav);
+					
+					// conv.encode_completed ++;
 				}
 
 				/* lame SOURCE WAV -> DESTINATION MP3
@@ -331,7 +339,7 @@ void filemp3oggconv_set_flags_before_conversion (void)
 					if (FILE_IS_OGG == detail->type_infosong_file_is) conv.total_convert ++;
 					
 					PConvMp3Ogg->destwav  = g_strdup_printf ("%s/tmp.wav", conv.TmpRep);
-					PConvMp3Ogg->destsox  = g_strdup_printf ("%s/tmp_sox.wav.", conv.TmpRep);
+					PConvMp3Ogg->destsox  = g_strdup_printf ("%s/tmp_sox.wav", conv.TmpRep);
 					PConvMp3Ogg->destmp3  = g_strdup_printf ("%s/tmp.mp3", conv.TmpRep);
 					PConvMp3Ogg->destogg  = g_strdup_printf ("%s/tmp.ogg", conv.TmpRep);
 
