@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -62,23 +62,23 @@
 */
 
 typedef struct {
-	gboolean         bool_etat;
-	gchar		*MessUser;
+	gboolean         bool_etat;			// 
+	gchar		*MessUser;			// 
 	
-	gint             NbrElementsInList;
-	gint             ElementActif;
-	double           total_percent;
+	gint             NbrElementsInList;		// 
+	gint             ElementActif;			// 
+	double           total_percent;			// 
 	
-	pthread_t        nmr_tid;
-	guint            handler_timeout;
-	gboolean         bool_thread_end;
+	pthread_t        nmr_tid;			// 
+	guint            handler_timeout;		// 
+	gboolean         bool_thread_end;		// 
 
-	gboolean         bool_compteur;
-	gint             pass_conv;
+	gboolean         bool_compteur;			// 
+	gint             pass_conv;			// 
 	
-	gboolean         bool_update;
+	gboolean         bool_update;			// 
 	
-	gboolean	 BoolWindScanUsed;
+	gboolean	 BoolWindScanUsed;		// 
 	
 } VAR_FILE_SCAN_DB;
 
@@ -113,7 +113,7 @@ static void FileScanDB_thread (void *arg)
 
 				VarFileScanDB.bool_compteur = TRUE;
 				
-				detail->LevelMix          = FicLevelMix;
+				detail->LevelMix         = FicLevelMix;
 				info->LevelDbfs.NewLevel = FicLevelMix;
 				info->LevelDbfs.level    = GetInfo_level_get_from (FILE_IS_WAV, detail->namefile);
 				
@@ -129,7 +129,7 @@ static void FileScanDB_thread (void *arg)
 				
 				VarFileScanDB.bool_compteur = TRUE;
 			
-				detail->LevelMix          = FicLevelMix;
+				detail->LevelMix         = FicLevelMix;
 				info->LevelDbfs.NewLevel = FicLevelMix;
 				info->LevelDbfs.level    = GetInfo_level_get_from (FILE_IS_OGG, detail->namefile);
 				
@@ -167,8 +167,10 @@ static void FileScanDB_thread (void *arg)
 static gint FileScanDB_timeout (gpointer data)
 {
 	if (VarFileScanDB.bool_etat == TRUE) {
-		g_free (VarFileScanDB.MessUser);
-		VarFileScanDB.MessUser = NULL;
+		if( NULL != VarFileScanDB.MessUser ) {
+			g_free (VarFileScanDB.MessUser);
+			VarFileScanDB.MessUser = NULL;
+		}
 		VarFileScanDB.bool_etat = FALSE;
 	}
 	
