@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -671,10 +671,14 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	process_goto_timeout ();
 	
 	// ADMINISTRATOR MODE ?
-	if (0 == getuid()) {
+	if( 0 == getuid() ) {
 		wininfo_create (
 			_("MODE ADMINISTRATEUR"),
-			_("Vous ne devriez pas utiliser XCFA sous ROOT !"),
+			  "\n",
+			_("   Vous ne devriez pas utiliser   "),
+			  "\n",
+			_("   XCFA sous ROOT !"),
+			  "\n",
 			"");
 	}
 	
