@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -44,7 +44,7 @@
 #include <sys/stat.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <fcntl.h>
+#include <fcntl.h>	// PROCESSUS NON-BLOQUANT
 #include <string.h>
  
 #ifdef ENABLE_STATIC_LIBRARY
@@ -163,8 +163,11 @@ void mplayer_create_fifo (void)
 		gint	descripteur;
 	 	
 	 	descripteur = open (XCFA_TMP_FIFO, O_RDWR);
+	 	
+		// LE FICHIER EST OUVERT EN MODE « NON-BLOQUANT »
 	 	status = fcntl(descripteur, F_GETFL);
 	 	status = fcntl(descripteur, F_SETFL, status | O_NONBLOCK);
+	 	
 	 	close (descripteur);
 	 }
 }
