@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -313,7 +313,7 @@ void Parse_allocate_function (PARSE_TYPE p_ParseType, CD_TYPE_TAG p_CdTypeTag, g
 		//
 		New->StringReplaceOld = g_strdup_printf ("%s", Str);
 		New->StringReplaceNew = g_strdup_printf ("%s", PtrEnd);
-		
+
 		// STOCKE LA STRUCTURE DANS LA LISTE
 		if( p_ParseType == PARSE_TYPE_STOCKAGE_CD ) {
 			VarParse.ListParseStockCd = g_list_append (VarParse.ListParseStockCd, New);
@@ -332,8 +332,13 @@ void Parse_allocate_function (PARSE_TYPE p_ParseType, CD_TYPE_TAG p_CdTypeTag, g
 void Parse_entry (PARSE_TYPE p_ParseType)
 {
 	gchar		*PtrTemplate = NULL;
+	gchar		*BeginPtrTemplate = NULL;
+	gchar		*NewPtrTemplate = NULL;
 	gchar		 Str [ 10 ];
 	gboolean	 BoolTagOk = FALSE;
+	gboolean	 BoolSet = FALSE;
+	
+	PRINT_FUNC_LF();
 	
 	// QUELLE LIGNE ANALYSER ?
 	if( p_ParseType == PARSE_TYPE_STOCKAGE_CD ) {
@@ -344,6 +349,8 @@ void Parse_entry (PARSE_TYPE p_ParseType)
 		PRINT("ERREUR PARAMETRE");
 		return;
 	}
+	BeginPtrTemplate = PtrTemplate;
+	NewPtrTemplate   = g_strdup( PtrTemplate );
 	
 	// REMOVE LISTE
 	Parse_remove (p_ParseType, FALSE);
@@ -544,6 +551,26 @@ void Parse_entry (PARSE_TYPE p_ParseType)
 				PtrTemplate ++;
 			}
 			Parse_allocate (p_ParseType, CD_TAG_DEFAULT, Str);
+
+			if( *Str == '/' ) {
+				gchar *Ptr = PtrTemplate;
+				while( Ptr > BeginPtrTemplate && *Ptr != '/' ) Ptr --;
+				/*
+				if( p_ParseType == PARSE_TYPE_STOCKAGE_CD ) {
+					if( Ptr > BeginPtrTemplate ) {
+						if( *(Ptr -1) == '/' ) {
+							g_print( "DOUBLON  PARSE_TYPE_STOCKAGE_CD\n" );
+							BoolSet = TRUE;
+							*( NewPtrTemplate + (gint)(Ptr - BeginPtrTemplate) ) = '_';
+						}
+					}
+				} else 
+				*/
+				if( p_ParseType == PARSE_TYPE_TITLE_CD ) {
+					*( NewPtrTemplate + (gint)(Ptr - BeginPtrTemplate) ) = '_';
+					BoolSet = TRUE;
+				}
+			}
 		}
 	}
 	
@@ -552,6 +579,14 @@ void Parse_entry (PARSE_TYPE p_ParseType)
 		Parse_allocate (p_ParseType, CD_TAG_TITLE, NULL);
 	}
 	
+	if( TRUE == BoolSet ) {
+		if( p_ParseType == PARSE_TYPE_STOCKAGE_CD ) {
+			gtk_entry_set_text( GTK_ENTRY(var_cd.Adr_entry_stockage_cdaudio), NewPtrTemplate );
+		} else if( p_ParseType == PARSE_TYPE_TITLE_CD ) {
+			gtk_entry_set_text( GTK_ENTRY(var_cd.Adr_entry_new_titre_cdaudio), NewPtrTemplate );
+		}
+	}
+	
 	// Parse_debug (p_ParseType);
 }
 // 
@@ -769,8 +804,9 @@ gchar *Parse_get_line (PARSE_TYPE p_ParseType, gint p_Num_cell)
 		// DEUX CARACTERES SLASH ( // ) NE PEUVENT ETRE COTE A COTE
 		Ptr = gstr->str;
 		while(  *Ptr ) {
-			// if( '/' == *Ptr) *Ptr = '-';
-			if( '/' == *Ptr && '/' == *(Ptr +1) ) *Ptr = '-';
+			if( '/' == *Ptr && '/' == *(Ptr +1) ) {
+				*Ptr = '_';
+			}
 			Ptr ++;
 		}
 	}
