@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -333,17 +333,6 @@ NULL,								// PIXBUF TREE-VIEW
 " vorbisgain",							// PAQUAGE
 gettext_noop(" Normaliseur de fichier ogg")},			// DESCRIPTION
 
-{"wavsplit",							// PACKAGEDEBIAN_64
-"wavsplit",							// PACKAGEDEBIAN_32
-"wavsplit",							// NAME1
-"",								// NAME2
-"",								// NAME3
-&PrgInit.bool_wavsplit,						// FOUND
-NULL,								// NAME TREE-VIEW
-NULL,								// PIXBUF TREE-VIEW
-" wavsplit",							// PAQUAGE
-gettext_noop(" Decoupage de fichiers sans decodage")},		// DESCRIPTION
-
 {"wavpack",							// PACKAGEDEBIAN_64
 "wavpack",							// PACKAGEDEBIAN_32
 "wavpack",							// NAME1
@@ -573,7 +562,6 @@ gboolean prginit_get_etat (void)
 		PrgInit.bool_lsdvd &
 		PrgInit.bool_vorbisgain &
 		PrgInit.bool_mp3gain &
-		PrgInit.bool_wavsplit &
 		PrgInit.bool_shntool &
 		PrgInit.bool_aacplusenc;
 	
