@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -56,15 +56,6 @@
 
 
 
-typedef struct {
-	gchar		*OldRep;
-	gchar		*TmpRep;
-
-} VAR_SPLITCUE;
-
-VAR_SPLITCUE VarSplitCue;
-
-
 
 extern VAR_SPLIT VarSplit;
 
@@ -193,7 +184,8 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 		return (NULL);
 	}
 	if (FALSE == FileIs_g_str_has_suffix (PathNameSong, ".WAV")) {
-		g_print ("====\n%s\n----\n%s\t%s\n\t\tFILE NOT IN: .wav\n====\n", p_pathname, buf, PathNameSong);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("====\n%s\n----\n%s\t%s\n\t\tFILE NOT IN: .wav\n====\n", p_pathname, buf, PathNameSong);
 		wininfo_create (
 			_("Erreur"),
 			_("Pas de fichier WAV dans le cue-file !"),
@@ -258,28 +250,33 @@ gchar *SplitCue_read_cue_file (gchar *p_pathname)
 	
 	// TESTER LA COHERENCE DES DATAS
 	BoolResultOk = TRUE;
-	g_print ("\n");
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\n");
 	for (IndicePoints = 0; VarSplit.Selecteur [ IndicePoints ] . Nmr != -1; IndicePoints ++) {
-		g_print ("[ %2d ]   TIME = %05d  BEGIN = %5d  END = %5d  PERCENTBEGIN = %f  PERCENTEND = %f\n",
-			VarSplit.Selecteur [ IndicePoints ] . Nmr,
-			FileTimeSec,
-			(gint)VarSplit.Selecteur [ IndicePoints ] . BeginPaint,
-			(gint)VarSplit.Selecteur [ IndicePoints ] . EndPaint,
-			VarSplit.Selecteur [ IndicePoints ] . PercentBegin,
-			VarSplit.Selecteur [ IndicePoints ] . PercentEnd
-			);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("[ %2d ]   TIME = %05d  BEGIN = %5d  END = %5d  PERCENTBEGIN = %f  PERCENTEND = %f\n",
+				VarSplit.Selecteur [ IndicePoints ] . Nmr,
+				FileTimeSec,
+				(gint)VarSplit.Selecteur [ IndicePoints ] . BeginPaint,
+				(gint)VarSplit.Selecteur [ IndicePoints ] . EndPaint,
+				VarSplit.Selecteur [ IndicePoints ] . PercentBegin,
+				VarSplit.Selecteur [ IndicePoints ] . PercentEnd
+				);
 		if ((gint)VarSplit.Selecteur [ IndicePoints ] . BeginPaint > (gint)VarSplit.Selecteur [ IndicePoints ] . EndPaint) {
 			BoolResultOk = FALSE;
-			g_print ("\t--- ERREUR [ 1 ] DE DATAS DANS LE FICHIER CUE !!! ---\n");
+			if( TRUE == OptionsCommandLine.BoolVerboseMode )
+				g_print ("\t--- ERREUR [ 1 ] DE DATAS DANS LE FICHIER CUE !!! ---\n");
 		}
 		if (VarSplit.Selecteur [ IndicePoints +1 ] . Nmr != -1) {
 			if ((gint)VarSplit.Selecteur [ IndicePoints ] . EndPaint > (gint)VarSplit.Selecteur [ IndicePoints +1 ] . BeginPaint) {
 				BoolResultOk = FALSE;
-				g_print ("\t--- [ 2 ] ERREUR DE DATAS DANS LE FICHIER CUE !!! ---\n");
+				if( TRUE == OptionsCommandLine.BoolVerboseMode )
+					g_print ("\t--- [ 2 ] ERREUR DE DATAS DANS LE FICHIER CUE !!! ---\n");
 			}
 		}
 	}
-	g_print ("\n");
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\n");
 	
 	// ERREUR DE DATAS DANS LE FICHIER CUE !!!
 	if (FALSE == BoolResultOk) {
@@ -343,8 +340,10 @@ void on_button_gen_cue_split_clicked (GtkButton *button, gpointer user_data)
 		S = sec % 60;
 		C = hundr;
 		
-		g_print ("[ %02d ] ", IndicePoints);
-		g_print ("%02d:%02d:%02d   ", M, S, C);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print ("[ %02d ] ", IndicePoints);
+			g_print ("%02d:%02d:%02d   ", M, S, C);
+		}
 		
 		Percent = VarSplit.Selecteur [ IndicePoints ] . PercentEnd;
 		sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
@@ -355,11 +354,14 @@ void on_button_gen_cue_split_clicked (GtkButton *button, gpointer user_data)
 		S = sec % 60;
 		C = hundr;
 		
-		g_print ("%02d:%02d:%02d", M, S, C);
-		g_print ("\n");
+		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+			g_print ("%02d:%02d:%02d", M, S, C);
+			g_print ("\n");
+		}
 	}
 	
-	g_print ("\n");
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\n");
 	
 	// NOM DU CUE
 	/*PathNameFileCue = g_strdup (VarSplit.PathNameFile);
@@ -384,9 +386,10 @@ void on_button_gen_cue_split_clicked (GtkButton *button, gpointer user_data)
 	NameFileWav = g_strdup (Ptr);
 	
 	// DEBUG
-	g_print ("PathNameFileCue = %s\n", PathNameFileCue);
-	g_print ("NameFileWav     = %s\n", NameFileWav);
-	
+	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
+		g_print ("PathNameFileCue = %s\n", PathNameFileCue);
+		g_print ("NameFileWav     = %s\n", NameFileWav);
+	}
 	// CHANGER LE NOM DU FICHIER CUE SI IL EXIST
 	if (TRUE == libutils_test_file_exist (PathNameFileCue)) {
 		PRINT("PathNameFileCue  EXIST");
@@ -409,13 +412,15 @@ void on_button_gen_cue_split_clicked (GtkButton *button, gpointer user_data)
 		}
 		g_free (PathFileCue);		PathFileCue = NULL;
 		g_free (NameFileCue);		NameFileCue = NULL;
-		g_print ("NOUVEAU PathNameFileCue = %s\n", PathNameFileCue);
+		if( TRUE == OptionsCommandLine.BoolVerboseMode )
+			g_print ("NOUVEAU PathNameFileCue = %s\n", PathNameFileCue);
 	}	
 	
 	fp = fopen (PathNameFileCue, "w");
 	
 	// PRODUCTION DU FICHIER CUE
-	g_print ("\n");
+	if( TRUE == OptionsCommandLine.BoolVerboseMode )
+		g_print ("\n");
 	fprintf (fp,   "REM Cue file written by Xcfa\n\n");
 	fprintf (fp,   "PERFORMER \"%s\"\n", "CHANTEUR");
 	fprintf (fp,   "TITLE \"%s\"\n", "TITRE DISQUE");
@@ -465,130 +470,12 @@ void on_button_gen_cue_split_clicked (GtkButton *button, gpointer user_data)
 	g_free (PathNameFileCue);	PathNameFileCue = NULL;
 	g_free (NameFileWav);		NameFileWav = NULL;
 }
-
-
-/*
-	CUE/
-		jazz
-		jazz.cue
-	
-	// DEBUT 
-	$ wavsplit --Hours ./jazz.wav 0:00:00 0:03:00
-
-	CUE/
-		jazz
-		jazz.cue
-		jazz/
-			01.wav
-			02.wav <--- Result
-			03.wav
-	
-	// MILIEU
-	$ wavsplit --Hours ./jazz.wav 0:03:03 0:06:05
-	
-	CUE/
-		jazz
-		jazz.cue
-		jazz/
-			01.wav
-			02.wav  <--- Result
-			03.wav
-	
-	// FIN
-	$ wavsplit --Hours ./jazz.wav  0:12:49 0:15:42
-
-	CUE/
-		jazz
-		jazz.cue
-		jazz/
-			01.wav
-			02.wav <--- Result
-			03.wav
-*/
 // 
 // 
 // 
 void SplitCue_thread (void)
 {
-	gchar	*Src = NULL;
-	gchar	*Dest = NULL;
-	gchar	*TmpWav = NULL;
-	gint	pos = 0;
-	gint	H, M, S, C, hundr;
-	gint	sec;
-	gdouble	dsec;
-	gdouble	Percent;
-	gdouble	TimeSongSec;
-	gint	Plage;
-	gchar	*BeginTime = NULL;
-	gchar	*EndTime = NULL;
-	
-	PRINT_FUNC_LF();
-	conv.bool_thread_conv = TRUE;
-	
-	// COPIE DU FICHIER ORIGINAL VERS LE DOSSIER TEMPRAIRE
-	Src  = g_strdup (VarSplit.PathNameFile);
-	TmpWav = g_strdup_printf ("%s/xcfa.wav", VarSplitCue.TmpRep);
-	conv_copy_src_to_dest (Src, TmpWav);
-	g_free (Src);	Src  = NULL;
-	
-	// DUREE TOTALE EXPRIMEE EN SECONDES
-	TimeSongSec = VarSplit.Tags->SecTime;
-	
-	for (Plage = 0; VarSplit.Selecteur [ Plage ] . Nmr != -1; Plage ++) {
-		
-		if (TRUE == WindScan_close_request ()) {
-			break;
-		}
-		
-		// VALEUR DEBUT DE LA PLAGE
-		Percent = VarSplit.Selecteur [ Plage ] . PercentBegin;
-		sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
-		dsec  = ((gdouble)TimeSongSec * (gdouble)Percent) / 100.0;
-		hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
-		H = (sec / 60) / 60;
-		M = (sec / 60) % 60;
-		S = sec % 60;
-		C = hundr;
-		BeginTime = g_strdup_printf ("%02d:%02d:%02d:%02d", H,M,S,C);
-		
-		// VALEUR FIN DE LA PLAGE
-		Percent = VarSplit.Selecteur [ Plage ] . PercentEnd;
-		sec = (gint) (((gdouble)TimeSongSec * (gdouble)Percent) / 100.0);
-		dsec  = ((gdouble)TimeSongSec *(gdouble)Percent) / 100.0;
-		hundr = ((gdouble)dsec - (gdouble)sec) * 100.0;
-		H = (sec / 60) / 60;
-		M = (sec / 60) % 60;
-		S = sec % 60;
-		C = hundr;
-		EndTime   = g_strdup_printf ("%02d:%02d:%02d:%02d", H,M,S,C);
-		
-		// $ wavsplit --Hours ./xcfa.wav BeginTime EndTime
-		
-		// EXTRACTION AVEC WAVSPLIT
-		pos = filelc_get_command_line_nice ();
-		conv.ArgConv [ pos++ ] = g_strdup ("wavsplit");
-		conv.ArgConv [ pos++ ] = g_strdup (TmpWav);
-		conv.ArgConv [ pos++ ] = g_strdup ("--Hours");
-		conv.ArgConv [ pos++ ] = g_strdup (BeginTime);
-		conv.ArgConv [ pos++ ] = g_strdup (EndTime);
-		conv.ArgConv [ pos++ ] = NULL;
-		
-		// g_print ("BeginTime = %s    EndTime = %s\n", BeginTime, EndTime);
-		conv_to_convert (FALSE, WAVSPLIT_EXTRACT, "WAVSPLIT_EXTRACT");
-		filelc_get_command_line_remove ();
-		g_free (BeginTime);	BeginTime = NULL;
-		g_free (EndTime);	EndTime = NULL;
-		
-		// COPIE DE L EXTRACTION VERS LA DESTINATION
-		Src  = g_strdup_printf ("%s/xcfa/02.wav", VarSplitCue.TmpRep);
-		Dest = g_strdup_printf ("%s/%02d_xcfa_split.wav", Config.PathDestinationSplit, Plage +1);
-		conv_copy_src_to_dest (Src, Dest);
-		g_free (Src);	Src  = NULL;
-		g_free (Dest);	Dest = NULL;
-	}
-		
-	g_free (TmpWav);	TmpWav = NULL;
+	SplitWav_extract();
 	
 	PRINT("FIN THREAD SPLIT EXTRACT");
 	conv.bool_thread_conv = FALSE;
@@ -602,16 +489,7 @@ static gint SplitCue_timeout (gpointer data)
 	if (TRUE == conv.bool_thread_conv) {
 	
 	}
-	else {
-		// SE PLACER DANS LE DOSSIER D ORIGINE
-		g_chdir (VarSplitCue.OldRep);
-		g_free (VarSplitCue.OldRep);	VarSplitCue.OldRep = NULL;
-		
-		// REMOVE DOSSIER TEMPORAIRE
-		if (NULL != VarSplitCue.TmpRep)  {
-			VarSplitCue.TmpRep  = libutils_remove_temporary_rep (VarSplitCue.TmpRep);
-		}
-		
+	else {		
 		PRINT("FIN TIMEOUT SPLIT EXTRACT");
 		gtk_timeout_remove (conv.handler_timeout_conv);
 		
@@ -627,29 +505,11 @@ void on_button_action_split_clicked (GtkButton *button, gpointer user_data)
 	pthread_t  nmr_tid;
 	
 	PRINT_FUNC_LF();
-	
-	if (FALSE == PrgInit.bool_wavsplit) {
-		wininfo_create (
-			_("wavsplit absent"),
-			_("wavsplit est absent de votre configuration."),
-			  "\n\n",
-			_("Veuillez l'installer."),
-			  "");
-		return;
-	}
-	
+		
 	WindScan_open ("Split file", WINDSCAN_PULSE);
 	WindScan_set_label ("<b><i>Split file ...</i></b>");
 	conv_reset_struct (WindScan_close_request);
 	
-	// NOUVEAU DOSSIER AND GOTO
-	VarSplitCue.OldRep = g_get_current_dir ();
-	if (NULL == VarSplitCue.TmpRep)  {
-		VarSplitCue.TmpRep  = libutils_create_temporary_rep (Config.PathnameTMP, PATH_TMP_XCFA_WAVSPLIT);
-	}
-	// SE PLACER DANS LE DOSSIER TEMPORAIRE
-	g_chdir (VarSplitCue.TmpRep);
-
 	conv.bool_thread_conv = TRUE;
 	PRINT("DEBUT THREAD SPLIT EXTRACT");
 	pthread_create (&nmr_tid, NULL ,(void *)SplitCue_thread, (void *)NULL);
