@@ -3,7 +3,7 @@
  *  project   : xcfa
  *  with      : Gtk-2
  *
- *  copyright : (C) 2003 - 2011 by Claude Bulin
+ *  copyright : (C) 2003 - 2012 by Claude Bulin
  *
  *  xcfa - GTK+ implementation of the GNU shell command
  *  GNU General Public License
@@ -680,7 +680,7 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 	gint		tmp = 0;
 	gint		points;
 	unsigned char	devbuf[ BLOCK_SIZE +10 ];
-	WAVE		son;
+	WAVE		WaveHeader;
 	TYPE_FILE_IS	TypeFileIs = FILE_IS_NONE;
 
 	PRINT_FUNC_LF();
@@ -701,14 +701,14 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 		}
 	}
 	
-	if (FALSE == tagswav_read_file (PathNameFile, &son)) {
-		tagswav_close_file (&son);
+	if (FALSE == tagswav_read_file (PathNameFile, &WaveHeader)) {
+		tagswav_close_file (&WaveHeader);
 		if( TRUE == OptionsCommandLine.BoolVerboseMode )
 			printf ("\nImpossible d'ouvrir le fichier : \"%s\"\n\n", PathNameFile);
 		return FALSE;
 	}
-	pFile = son.file;
-	son.file = NULL;
+	pFile = WaveHeader.file;
+	WaveHeader.file = NULL;
 	
 	if (pFile == NULL) {
 		PRINT_FUNC_LF();
@@ -716,9 +716,9 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 			g_print ("\nImpossible d'ouvrir le fichier : \"%s\"\n\n", PathNameFile);
 		return FALSE;
 	}
-	VarSplit.nBitsPerSample = son.FMT.BitsPerSample;
+	VarSplit.nBitsPerSample = WaveHeader.FMT.BitsPerSample;
 	
-	switch (son.FMT.BitsPerSample) {
+	switch (WaveHeader.FMT.BitsPerSample) {
 	case 8 :
 	case 16 :
 	case 24 :
@@ -732,7 +732,7 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 		if( TRUE == OptionsCommandLine.BoolVerboseMode )
 			g_print("Seuls ces formats de bitrates : 8 16 24 et 32 sont pris en charge pour la lecture\n"
 				"Format de bitrate [ %d ] non prit en charge\n", 
-				son.FMT.BitsPerSample);
+				WaveHeader.FMT.BitsPerSample);
 			
 		// DEL ALLOC MEMORY
 		if (NULL != VarSplit.Tab) {
@@ -741,7 +741,7 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 		return FALSE;
 		}
 	}
-	VarSplit.nTotalChunckSize = son.DATA.Subchunk2Size;
+	VarSplit.nTotalChunckSize = WaveHeader.DATA.Subchunk2Size;
 	found = TRUE;
 		
 	// DEL ALLOC MEMORY
@@ -752,21 +752,21 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 	
 	if (found == TRUE) {
 			
-		VarSplit.TotalAllocation = sizeof(POINTS_FILE) * ((son.DATA.Subchunk2Size / BLOCK_SIZE) +10);
+		VarSplit.TotalAllocation = sizeof(POINTS_FILE) * ((WaveHeader.DATA.Subchunk2Size / BLOCK_SIZE) +10);
 		VarSplit.Tab = (POINTS_FILE *)g_malloc0 (VarSplit.TotalAllocation + 10);
 		
 		points = 0;
-		if (son.FMT.BitsPerSample <= 0) son.FMT.BitsPerSample = 8;
+		if (WaveHeader.FMT.BitsPerSample <= 0) WaveHeader.FMT.BitsPerSample = 8;
 
 		// TRAITEMENT UNIQUES: 8, 16, 24 et 32 bits
-		switch (son.FMT.BitsPerSample) {
+		switch (WaveHeader.FMT.BitsPerSample) {
 			case 8 :
 			case 16 :
 			case 24 :
 			case 32 :
 				// PRE - CALCUL
 
-				ChannelNext = (son.FMT.NumChannels -1) * (son.FMT.BitsPerSample / 8);
+				ChannelNext = (WaveHeader.FMT.NumChannels -1) * (WaveHeader.FMT.BitsPerSample / 8);
 
 				// LECTURE DES DATAS
 				// #define BLOCK_SIZE	2352
@@ -777,17 +777,17 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 
 					for (Indice = 0; Indice < Ret; Indice++) {
 
-						if (son.FMT.BitsPerSample == 8) {
+						if (WaveHeader.FMT.BitsPerSample == 8) {
 							
 							tmp = devbuf [ Indice ];
 							tmp -= 128;
 						}
-						else if (son.FMT.BitsPerSample == 16) {
+						else if (WaveHeader.FMT.BitsPerSample == 16) {
 							
 							tmp = (gchar)devbuf [ Indice +1 ] << 8 | (gchar)devbuf [ Indice ];
 							Indice ++;
 						}
-						else if (son.FMT.BitsPerSample == 24) {
+						else if (WaveHeader.FMT.BitsPerSample == 24) {
 							
 							tmp  = (gchar)devbuf [ Indice +0 ] >> 16;
 							tmp += (gchar)devbuf [ Indice +1 ] >> 8;
@@ -795,7 +795,7 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 														
 							Indice += 2;
 						}
-						else if (son.FMT.BitsPerSample == 32) {
+						else if (WaveHeader.FMT.BitsPerSample == 32) {
 							
 							tmp  = (gchar)devbuf [ Indice +0 ] >> 24;
 							tmp += (gchar)devbuf [ Indice +1 ] >> 16;
@@ -825,7 +825,7 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 			default :
 				PRINT("Ne doit pas arriver ici  !!!!");
 				if( TRUE == OptionsCommandLine.BoolVerboseMode )
-					g_print ("Ce format n'est pas pris en charge : %d\n", son.FMT.BitsPerSample);
+					g_print ("Ce format n'est pas pris en charge : %d\n", WaveHeader.FMT.BitsPerSample);
 				fclose (pFile);
 				return FALSE;
 		}
@@ -1035,8 +1035,7 @@ void SplitSpectre_draw_lines (void)
 		SelEnd   = SplitSelector_get_pos_end (VarSplit.SelecteurActif);
 		begin    = save_begin;
 				
-		for (points = 0; begin < end; begin ++, points ++) { 
-					
+		for (points = 0; begin < end; begin ++, points ++) { 		
 			
 			// MaxScale_0
 			if (begin >= SelBegin &&  begin <= SelEnd) {
@@ -1137,7 +1136,7 @@ void SplitSpectre_draw_lines (void)
 		gdk_gc_destroy (gc);
 	}
 }
-// AFFICHAGE DU CURSEUR EN MODE PLAY: GAN DE TEMPS POUR LE CPU
+// AFFICHAGE DU CURSEUR EN MODE PLAY: GAIN DE TEMPS POUR LE CPU
 //
 void SplitSpectre_draw_lines_play( void )
 {
