@@ -3,7 +3,7 @@
  * project   : xcfa
  * with      : Gtk-2
  *
- * copyright : (C) 2010 - 2011 by Claude Bulin
+ * copyright : (C) 2003 - 2012 by Claude Bulin
  *
  * xcfa - Creation d'une base de programmation en langage C de type GNU avec les autotools
  * GNU General Public License
@@ -28,7 +28,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -41,7 +41,6 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
-#include <fcntl.h>
 #include <string.h>
 
 #if defined(FILE_DEBIAN_VTE_H_IS_OK)
